@@ -43,8 +43,10 @@ def _print_s400_instructions(info):
     util._print_sub_header("S400's web user interface (UI)")
     print("Next, you need to access the web UI of the S400:\n")
     _item(
-        "Configure you host's network interface to the same subnet as the S400"
-        ". By default, the S400 is configured with IP address 192.168.1.2 on "
+        "Configure you host's network interface to the same subnet as the S400."
+    )
+    print()
+    _print("By default, the S400 is configured with IP address 192.168.1.2 on "
         "LAN1 and 192.168.2.2 on LAN2. So, if you are connecting to LAN1, "
         "make sure your host's network interface has IP address 192.168.1.x, "
         "where \"x\" could be any number higher than 2. For example, you could "
@@ -64,6 +66,10 @@ def _print_s400_instructions(info):
     util.prompt_for_enter()
 
     util._print_sub_header("S400 Configurations")
+
+    _print("Next, you need to configure the S400 to receive the Blockstream "
+           "Satellite signal.")
+
     print("1. First you need to log in as admin, on the top right of the page.")
     _item("Password: \"password\"")
     print()
@@ -117,8 +123,8 @@ def _print_s400_instructions(info):
           "on the antenna pointing afterwards.")
     print()
 
-    print("4. Go to Services > Tun1:\n")
-    print("Scroll to \"Manage MPE PIDs\"")
+    print("4. Go to Services > RF1:\n")
+    print("Scroll to \"Manage MPE/ULE PIDs\"")
     for pid in defs.pids:
         print("- Enter %d on \"New PID\" and click \"Add\"." %(pid))
     _item("Apply")
@@ -130,6 +136,10 @@ def _print_s400_instructions(info):
           "configure the IP addresses. Note LAN 1 is the interface that "
           "will deliver the data packets received over satellite, whereas "
           "LAN2 is optional and exclusively for management.")
+    _item("""If you are configuring the second RF interface on the S400 for a
+    dual-satellite setup, on step 2, go to \"Interfaces > RF2\" instead of
+    \"RF1\". Correspondingly, on step 3, check the \"RF 2 Lock\" indicator,
+    and on step 4, go to \"Services > RF2\".""")
     print()
 
     util.prompt_for_enter()
@@ -157,6 +167,20 @@ def _print_s400_instructions(info):
 
         util.prompt_for_enter()
 
+    util._print_sub_header("Host Requirements")
+
+    _print("Next, make sure that you have all software pre-requisites "
+           "available in your host. Run:")
+
+    print("""
+    blocksat-cli deps install
+    """)
+
+    _print("""
+    NOTE: this command supports the apt, dnf, and yum package managers.""")
+
+    util.prompt_for_enter()
+
     util._print_sub_header("Host Configuration")
 
     _print("""
@@ -165,10 +189,15 @@ def _print_s400_instructions(info):
     by running:
     """)
 
-    print("\n```\nblocksat-cli standalone -i ifname\n```\n")
-    print(textwrap.fill("where \'ifname\' should be replaced with the name "
-                        "of the network interface that is connected to the "
-                        "S400."))
+    print("\n    sudo blocksat-cli standalone cfg\n\n")
+
+    _print("""If you would like to review the changes that will be made before
+    applying them, first run the command as a non-root user:
+    """)
+
+    print("\n    blocksat-cli standalone cfg\n\n")
+
+    util.prompt_for_enter()
 
 
 def _print_usb_rx_instructions(info):
@@ -210,13 +239,16 @@ def _print_usb_rx_instructions(info):
     virtual machine.
     """.format(name))
     _print("""
-    Next, install the drivers for the {0}. A helper script is available in the
-    `util` directory from the root of this repository:
+    Next, install the drivers for the {0}. First download the helper script by
+    running:
     """.format(name))
 
-    _item("From the util/ folder, run:")
+    print("    wget https://raw.githubusercontent.com/"
+          "Blockstream/satellite/master/util/tbsdriver.sh\n")
+
+    _item("Then, run the script:")
     print("""
-    ./tbsdriver.sh
+    bash tbsdriver.sh
     """)
     print("Once the script completes the installation, reboot the virtual machine.")
 
@@ -241,17 +273,17 @@ def _print_usb_rx_instructions(info):
     util._print_sub_header("Configure the Host")
 
     _print("""Next, you need to create and configure the network interfaces that
-    will output the IP traffic received via the TBS5927. You can see all
-    required configurations by running the following as a non-root user:""")
-
-    print("\n    blocksat-cli usb config\n")
-
-
-    _print("""To effectively apply the configurations, run the same command as
-    root, i.e., with sudo in front, as follows:""")
+    will output the IP traffic received via the TBS5927. You can apply all
+    configurations by running the following command:""")
 
     print("\n    sudo blocksat-cli usb config\n")
 
+    _print("""If you would like to review the changes that will be made before
+    applying them, first run the command as a non-root user:
+    """)
+
+    print("\n    blocksat-cli usb config\n")
+
     _print("""
     Note this command will define arbitrary IP addresses to the interfaces. If
     you need (or want) to define specific IP addresses instead, for example to
@@ -262,7 +294,7 @@ def _print_usb_rx_instructions(info):
 
     util._print_sub_header("Launch")
 
-    print("Finally, launch the DVB-S2 interface by running:")
+    print("Finally, start the receiver by running:")
 
     print("\n    blocksat-cli usb launch\n")
 
@@ -354,9 +386,10 @@ def _print_freq_info(info):
 
     util._print_header("Frequencies")
 
-    print("| Downlink %2s band frequency                     | %8.2f MHz |" %(sat['band'], sat['dl_freq']))
-    print("| Your LNB local oscillator (LO) frequency       | %8.2f MHz |" %(lo_freq))
-    print("| L-band frequency to configure on your receiver | %7.2f MHz  |" %(l_freq))
+    print("For your information, your setup relies on the following frequencies:\n")
+    print("| Downlink %2s band frequency            | %8.2f MHz |" %(sat['band'], sat['dl_freq']))
+    print("| LNB local oscillator (LO) frequency   | %8.2f MHz |" %(lo_freq))
+    print("| Receiver L-band frequency             | %7.2f MHz  |" %(l_freq))
     print()
 
     if (lnb['universal'] and (setup['type'] == defs.sdr_setup_type)):
